==> dotnet8_8.0.120-8.0.20.orig.tar.xz: src/razor/src/Compiler/Microsoft.AspNetCore.Razor.Language/test/CodeGeneration/DefaultCodeTargetTest.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using System.Linq;
using Xunit;

namespace Microsoft.AspNetCore.Razor.Language.CodeGeneration;

public class DefaultCodeTargetTest
{
    [Fact]
    public void Constructor_CreatesDefensiveCopy()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
        };

        // Act
        var target = new DefaultCodeTarget(options, extensions);

        // Assert
        Assert.NotSame(extensions, target);
    }

    [Fact]
    public void CreateWriter_DesignTime_CreatesDesignTimeNodeWriter()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDesignTimeDefault();
        var target = new DefaultCodeTarget(options, Enumerable.Empty<ICodeTargetExtension>());

        // Act
        var writer = target.CreateNodeWriter();

        // Assert
        Assert.IsType<DesignTimeNodeWriter>(writer);
    }

    [Fact]
    public void CreateWriter_Runtime_CreatesRuntimeNodeWriter()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();
        var target = new DefaultCodeTarget(options, Enumerable.Empty<ICodeTargetExtension>());

        // Act
        var writer = target.CreateNodeWriter();

        // Assert
        Assert.IsType<RuntimeNodeWriter>(writer);
    }

    [Fact]
    public void HasExtension_ReturnsTrue_WhenExtensionFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.HasExtension<MyExtension1>();

        // Assert
        Assert.True(result);
    }

    [Fact]
    public void HasExtension_ReturnsFalse_WhenExtensionNotFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension2(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.HasExtension<MyExtension1>();

        // Assert
        Assert.False(result);
    }

    [Fact]
    public void GetExtension_ReturnsExtension_WhenExtensionFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.GetExtension<MyExtension1>();

        // Assert
        Assert.Same(extensions[1], result);
    }

    [Fact]
    public void GetExtension_ReturnsFirstMatch_WhenExtensionFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
                new MyExtension2(),
                new MyExtension1(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.GetExtension<MyExtension1>();

        // Assert
        Assert.Same(extensions[1], result);
    }


    [Fact]
    public void GetExtension_ReturnsNull_WhenExtensionNotFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.CreateDefault();

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension2(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.GetExtension<MyExtension1>();

        // Assert
        Assert.Null(result);
    }

    private class MyExtension1 : ICodeTargetExtension
    {
    }

    private class MyExtension2 : ICodeTargetExtension
    {
    }
}

==> dotnet9_9.0.105-9.0.4.orig.tar.xz: src/razor/src/Compiler/Microsoft.AspNetCore.Razor.Language/test/CodeGeneration/DefaultCodeTargetTest.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using System.Linq;
using Xunit;

namespace Microsoft.AspNetCore.Razor.Language.CodeGeneration;

public class DefaultCodeTargetTest
{
    [Fact]
    public void Constructor_CreatesDefensiveCopy()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
        };

        // Act
        var target = new DefaultCodeTarget(options, extensions);

        // Assert
        Assert.NotSame(extensions, target);
    }

    [Fact]
    public void CreateWriter_DesignTime_CreatesDesignTimeNodeWriter()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.DesignTimeDefault;
        var target = new DefaultCodeTarget(options, Enumerable.Empty<ICodeTargetExtension>());

        // Act
        var writer = target.CreateNodeWriter();

        // Assert
        Assert.IsType<DesignTimeNodeWriter>(writer);
    }

    [Fact]
    public void CreateWriter_Runtime_CreatesRuntimeNodeWriter()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;
        var target = new DefaultCodeTarget(options, Enumerable.Empty<ICodeTargetExtension>());

        // Act
        var writer = target.CreateNodeWriter();

        // Assert
        Assert.IsType<RuntimeNodeWriter>(writer);
    }

    [Fact]
    public void HasExtension_ReturnsTrue_WhenExtensionFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.HasExtension<MyExtension1>();

        // Assert
        Assert.True(result);
    }

    [Fact]
    public void HasExtension_ReturnsFalse_WhenExtensionNotFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension2(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.HasExtension<MyExtension1>();

        // Assert
        Assert.False(result);
    }

    [Fact]
    public void GetExtension_ReturnsExtension_WhenExtensionFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.GetExtension<MyExtension1>();

        // Assert
        Assert.Same(extensions[1], result);
    }

    [Fact]
    public void GetExtension_ReturnsFirstMatch_WhenExtensionFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension1(),
                new MyExtension2(),
                new MyExtension1(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.GetExtension<MyExtension1>();

        // Assert
        Assert.Same(extensions[1], result);
    }


    [Fact]
    public void GetExtension_ReturnsNull_WhenExtensionNotFound()
    {
        // Arrange
        var options = RazorCodeGenerationOptions.Default;

        var extensions = new ICodeTargetExtension[]
        {
                new MyExtension2(),
                new MyExtension2(),
        };

        var target = new DefaultCodeTarget(options, extensions);

        // Act
        var result = target.GetExtension<MyExtension1>();

        // Assert
        Assert.Null(result);
    }

    private class MyExtension1 : ICodeTargetExtension
    {
    }

    private class MyExtension2 : ICodeTargetExtension
    {
    }
}
